@@ -732,7 +732,7 @@ class Commit(object):
                     to,
                 "amount":
                     '{:.{prec}f} {asset}'.format(
-                        float(amount), prec=3, asset='STEEM')
+                        float(amount), prec=3, asset='HIVE')
             })
 
         return self.finalizeOp(op, account, "active")
@@ -912,20 +912,15 @@ class Commit(object):
                 float(first(x.split(' ')))
                 for x in [reward_hbd, reward_hive, reward_vests]):
             a = Account(account)
-            reward_hive = a['reward_steem_balance']
-            reward_hbd = a['reward_sbd_balance']
+            reward_hive = a['reward_hive_balance']
+            reward_hbd = a['reward_hbd_balance']
             reward_vests = a['reward_vesting_balance']
 
-        if reward_hive[-4:] == 'HIVE':
-            reward_hive = reward_hive[:-4]+'STEEM'
-        if reward_hbd[-3:] == 'HBD':
-            reward_hbd = reward_hbd[:-3]+'SBD'
-
         op = operations.ClaimRewardBalance(
             **{
                 "account": account,
-                "reward_steem": reward_hive,
-                "reward_sbd": reward_hbd,
+                "reward_hive": reward_hive,
+                "reward_hbd": reward_hbd,
                 "reward_vests": reward_vests,
             })
         return self.finalizeOp(op, account, "posting")
@@ -1032,7 +1027,7 @@ class Commit(object):
                 [
                     ["account_creation_fee": x]
                     ["maximum_block_size": x]
-                    ["sbd_interest_rate": x]
+                    ["hbd_interest_rate": x]
                 ]
 
         """
@@ -1041,24 +1036,18 @@ class Commit(object):
         if not account:
             raise ValueError("You need to provide an account")
 
-        props_list = [["key", repr(PrivateKey(signing_key, prefix=self.hived.chain_params["prefix"]).pubkey)]]
-        for k in props:
-          if k == 'account_creation_fee':
-            if props[k][-4:] == 'HIVE':
-                props[k] = props[k][:-4]+'STEEM'
-          props_list.append([k, props[k]])
+        try:
+            PublicKey(signing_key)
+        except Exception as e:
+            raise e
 
         op = operations.WitnessSetProperties(
             **{
                 "owner": account,
-                "props": props_list,
+                "props": props,
                 "extensions": []
             })
-        tb = TransactionBuilder(None,hived_instance=self.hived,wallet_instance=self.wallet,no_broadcast=self.no_broadcast,expiration=self.expiration)
-        tb.appendOps([op])
-        tb.appendWif(signing_key)
-        tb.sign()
-        return tb.broadcast()
+        return self.finalizeOp(op, account, "active")
 
     def decode_memo(self, enc_memo):
         """ Try to decode an encrypted memo
