@@ -67,19 +67,7 @@ class Hived(HttpClient):
 
         assert chain in known_chains, "The chain you are connecting " + \
                                       "to is not supported"
-        #return known_chains.get(chain)
-        # temporarily get version and switch chain id after HF24
-        chain = known_chains.get(chain)
-        version = self.get_version()
-        if version['blockchain_version'] != '0.23.0':
-          i = 0
-          zeros = ''
-          while i < 56:
-            zeros = zeros+'0'
-            i = i+1
-          chain['chain_id'] = 'beeab0de'+zeros
-
-        return chain
+        return known_chains.get(chain)
 
     def get_replies(self, author, skip_own=True):
         """ Get replies for an author
